Package: solrium
Title: General Purpose R Interface to 'Solr'
Description: Provides a set of functions for querying and parsing data
    from 'Solr' (<https://solr.apache.org/>) 'endpoints' (local and
    remote), including search, 'faceting', 'highlighting', 'stats', and
    'more like this'. In addition, some functionality is included for
    creating, deleting, and updating documents in a 'Solr' 'database'.
Version: 1.2.0
Authors@R: c(
    person("Scott", "Chamberlain", role = c("aut", "cre"),
        email = "myrmecocystus@gmail.com", 
        comment = c(ORCID="0000-0003-1444-9135")),
    person(given = "rOpenSci",
        role = "fnd",
        comment = "https://ropensci.org/"))
License: MIT + file LICENSE
URL: https://github.com/ropensci/solrium (devel),
        https://docs.ropensci.org/solrium/ (user manual)
BugReports: https://github.com/ropensci/solrium/issues
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
Imports: utils, dplyr (>= 0.5.0), plyr (>= 1.8.4), crul (>= 0.4.0),
        xml2 (>= 1.0.0), jsonlite (>= 1.0), tibble (>= 1.4.2), R6
Suggests: testthat, knitr, rmarkdown
RoxygenNote: 7.1.1
X-schema.org-applicationCategory: Databases
X-schema.org-keywords: database, search, JSON, XML, API, web
X-schema.org-isPartOf: https://ropensci.org
NeedsCompilation: no
Packaged: 2021-05-18 21:19:53 UTC; sckott
Author: Scott Chamberlain [aut, cre] (<https://orcid.org/0000-0003-1444-9135>),
  rOpenSci [fnd] (https://ropensci.org/)
Maintainer: Scott Chamberlain <myrmecocystus@gmail.com>
Repository: CRAN
Date/Publication: 2021-05-19 04:40:13 UTC
Built: R 4.6.0; ; 2026-04-26 11:21:19 UTC; unix
