# Generated by roxygen2: do not edit by hand

S3method(add,data.frame)
S3method(add,list)
S3method(solr_parse,default)
S3method(solr_parse,ping)
S3method(solr_parse,sr_all)
S3method(solr_parse,sr_facet)
S3method(solr_parse,sr_group)
S3method(solr_parse,sr_high)
S3method(solr_parse,sr_mlt)
S3method(solr_parse,sr_search)
S3method(solr_parse,sr_stats)
S3method(solr_parse,update)
export(SolrClient)
export(add)
export(collection_addreplica)
export(collection_addreplicaprop)
export(collection_addrole)
export(collection_balanceshardunique)
export(collection_clusterprop)
export(collection_clusterstatus)
export(collection_create)
export(collection_createalias)
export(collection_createshard)
export(collection_delete)
export(collection_deletealias)
export(collection_deletereplica)
export(collection_deletereplicaprop)
export(collection_deleteshard)
export(collection_exists)
export(collection_list)
export(collection_migrate)
export(collection_overseerstatus)
export(collection_rebalanceleaders)
export(collection_reload)
export(collection_removerole)
export(collection_requeststatus)
export(collection_splitshard)
export(collections)
export(commit)
export(config_get)
export(config_overlay)
export(config_params)
export(config_set)
export(core_create)
export(core_exists)
export(core_mergeindexes)
export(core_reload)
export(core_rename)
export(core_requeststatus)
export(core_split)
export(core_status)
export(core_swap)
export(core_unload)
export(cores)
export(delete_by_id)
export(delete_by_query)
export(is.sr_facet)
export(is.sr_high)
export(is.sr_search)
export(ping)
export(schema)
export(solr_all)
export(solr_facet)
export(solr_get)
export(solr_group)
export(solr_highlight)
export(solr_json_request)
export(solr_mlt)
export(solr_optimize)
export(solr_parse)
export(solr_search)
export(solr_stats)
export(update_atomic_json)
export(update_atomic_xml)
export(update_csv)
export(update_json)
export(update_xml)
importFrom(R6,R6Class)
importFrom(crul,HttpClient)
importFrom(dplyr,bind_rows)
importFrom(jsonlite,fromJSON)
importFrom(plyr,rbind.fill)
importFrom(tibble,add_column)
importFrom(tibble,as_tibble)
importFrom(utils,URLdecode)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,read.table)
importFrom(xml2,read_xml)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_attrs)
importFrom(xml2,xml_children)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_find_first)
importFrom(xml2,xml_name)
importFrom(xml2,xml_text)
